@@ -6,6 +6,7 @@ import (
 	"testing"
 
 	"github.com/golang/mock/gomock"
+	"github.com/pborman/uuid"
 	"github.com/stretchr/testify/assert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/utils/pointer"
@@ -20,6 +21,7 @@ import (
 	"github.com/openshift/installer/pkg/types/none"
 	"github.com/openshift/installer/pkg/types/openstack"
 	"github.com/openshift/installer/pkg/types/openstack/validation/mock"
+	"github.com/openshift/installer/pkg/types/ovirt"
 	"github.com/openshift/installer/pkg/types/vsphere"
 )
 
@@ -90,16 +92,18 @@ func validVSpherePlatform() *vsphere.Platform {
 func validBareMetalPlatform() *baremetal.Platform {
 	iface, _ := net.Interfaces()
 	return &baremetal.Platform{
-		LibvirtURI:              "qemu+tcp://192.168.122.1/system",
-		BootstrapProvisioningIP: "127.0.0.1",
-		ClusterProvisioningIP:   "192.168.111.1",
-		Hosts:                   []*baremetal.Host{},
-		ExternalBridge:          iface[0].Name,
-		ProvisioningBridge:      iface[0].Name,
-		DefaultMachinePlatform:  &baremetal.MachinePool{},
-		APIVIP:                  "10.0.0.5",
-		IngressVIP:              "10.0.0.4",
-		DNSVIP:                  "10.0.0.2",
+		LibvirtURI:                   "qemu+tcp://192.168.122.1/system",
+		ProvisioningNetworkInterface: "ens3",
+		ProvisioningNetworkCIDR:      ipnet.MustParseCIDR("192.168.111.0/24"),
+		BootstrapProvisioningIP:      "192.168.111.1",
+		ClusterProvisioningIP:        "192.168.111.2",
+		Hosts:                        []*baremetal.Host{},
+		ExternalBridge:               iface[0].Name,
+		ProvisioningBridge:           iface[0].Name,
+		DefaultMachinePlatform:       &baremetal.MachinePool{},
+		APIVIP:                       "10.0.0.5",
+		IngressVIP:                   "10.0.0.4",
+		DNSVIP:                       "10.0.0.2",
 	}
 }
 
@@ -179,6 +183,16 @@ func validDualStackNetworkingConfig() *types.Networking {
 	}
 }
 
+func validOvirtPlatform() *ovirt.Platform {
+	return &ovirt.Platform{
+		ClusterID:       uuid.NewRandom().String(),
+		StorageDomainID: uuid.NewRandom().String(),
+		APIVIP:          "1.1.1.1",
+		DNSVIP:          "1.1.1.2",
+		IngressVIP:      "1.1.1.3",
+	}
+}
+
 func TestValidateInstallConfig(t *testing.T) {
 	cases := []struct {
 		name          string
@@ -468,7 +482,7 @@ func TestValidateInstallConfig(t *testing.T) {
 				c.Platform = types.Platform{}
 				return c
 			}(),
-			expectedError: `^platform: Invalid value: "": must specify one of the platforms \(aws, azure, baremetal, gcp, none, openstack, vsphere\)$`,
+			expectedError: `^platform: Invalid value: "": must specify one of the platforms \(aws, azure, baremetal, gcp, none, openstack, ovirt, vsphere\)$`,
 		},
 		{
 			name: "multiple platforms",
@@ -499,7 +513,7 @@ func TestValidateInstallConfig(t *testing.T) {
 				}
 				return c
 			}(),
-			expectedError: `^platform: Invalid value: "libvirt": must specify one of the platforms \(aws, azure, baremetal, gcp, none, openstack, vsphere\)$`,
+			expectedError: `^platform: Invalid value: "libvirt": must specify one of the platforms \(aws, azure, baremetal, gcp, none, openstack, ovirt, vsphere\)$`,
 		},
 		{
 			name: "invalid libvirt platform",
@@ -511,7 +525,7 @@ func TestValidateInstallConfig(t *testing.T) {
 				c.Platform.Libvirt.URI = ""
 				return c
 			}(),
-			expectedError: `^\[platform: Invalid value: "libvirt": must specify one of the platforms \(aws, azure, baremetal, gcp, none, openstack, vsphere\), platform\.libvirt\.uri: Invalid value: "": invalid URI "" \(no scheme\)]$`,
+			expectedError: `^\[platform: Invalid value: "libvirt": must specify one of the platforms \(aws, azure, baremetal, gcp, none, openstack, ovirt, vsphere\), platform\.libvirt\.uri: Invalid value: "": invalid URI "" \(no scheme\)]$`,
 		},
 		{
 			name: "valid none platform",
@@ -884,6 +898,17 @@ func TestValidateInstallConfig(t *testing.T) {
 			}(),
 			expectedError: `Invalid value: "DualStack": dual-stack IPv4/IPv6 is not supported for this platform, specify only one type of address`,
 		},
+
+		{
+			name: "valid ovirt platform",
+			installConfig: func() *types.InstallConfig {
+				c := validInstallConfig()
+				c.Platform = types.Platform{
+					Ovirt: validOvirtPlatform(),
+				}
+				return c
+			}(),
+		},
 		{
 			name: "cluster is not heteregenous",
 			installConfig: func() *types.InstallConfig {
